# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-06-15 21:40


from django.db import migrations
import djangocms_attributes_field.fields


class Migration(migrations.Migration):

    dependencies = [
        ('aldryn_bootstrap3', '0005_boostrap3imageplugin_use_original_image'),
    ]

    operations = [
        migrations.AddField(
            model_name='boostrap3buttonplugin',
            name='link_attributes',
            field=djangocms_attributes_field.fields.AttributesField(default=dict, verbose_name='Link Attributes'),
        ),
        migrations.AddField(
            model_name='bootstrap3carouselslideplugin',
            name='link_attributes',
            field=djangocms_attributes_field.fields.AttributesField(default=dict, verbose_name='Link Attributes'),
        ),
    ]
